@@ -471,8 +471,8 @@ class Map(View):
 
         var markers = L.markerClusterGroup();
 <% for (const item of items) { %>
-    <% if (item.title != "") { %>
-	  markers.addLayer(L.marker([<%= item.lat %>, <%= item.lon %>]).bindPopup("<%= String(item.title) %>"));
+    <% if (item.title.length > 0 ) { %>
+	  markers.addLayer(L.marker([<%= item.lat %>, <%= item.lon %>]).bindPopup("<%= String(item.title) %>" + "(<%= String(item.author) %>"));
     <% } else { %>
 	  markers.addLayer(L.marker([<%= item.lat %>, <%= item.lon %>]).bindPopup(""));
     <% } %>
